@@ -6,8 +6,9 @@ import functools
 import subprocess
 import time
 import traceback
+
 from abc import ABC, abstractmethod
-from typing import Any, Callable, List, Optional
+from typing import Any, Callable, Dict, List, Optional
 
 from packageurl import PackageURL  # type: ignore
 
@@ -164,7 +165,11 @@ class HopprPlugin(ABC):
     required_commands: List[str] = []
     supported_purl_types: List[str] = []
 
-    def __init__(self, context: Context, config: Any = None) -> None:
+    def __init__(
+        self,
+        context: Context,
+        config: Optional[Dict] = None,
+    ) -> None:
         self._logger: MemoryLogger
         self._start_time: float = 0.0
         self.context = context
