@@ -1,23 +1,24 @@
 """
 Collector plugin for raw files
 """
-import os
+
 import shutil
-import urllib
+
 from pathlib import Path
 from typing import Any
+from urllib.parse import unquote, urljoin, urlparse
 
 from packageurl import PackageURL  # type: ignore
 
 from hoppr import __version__
-from hoppr.base_plugins.collector import CollectorPlugin
+from hoppr.base_plugins.collector import SerialCollectorPlugin
 from hoppr.base_plugins.hoppr import hoppr_rerunner
 from hoppr.hoppr_types.cred_object import CredObject
 from hoppr.net import download_file
 from hoppr.result import Result
 
 
-class CollectRawPlugin(CollectorPlugin):
+class CollectRawPlugin(SerialCollectorPlugin):
     """
     Collector plugin for raw files
     """
@@ -32,21 +33,22 @@ class CollectRawPlugin(CollectorPlugin):
         """
         Copy a component to the local collection directory structure
         """
-        source_url = os.path.join(repo_url)
+        source_url = urlparse(repo_url)
 
         purl = PackageURL.from_string(comp.purl)
         subdir = None
         if purl.namespace is not None:
-            source_url += urllib.parse.unquote(purl.namespace) + "/"
-            subdir = urllib.parse.unquote(purl.namespace)
+            source_url = urlparse(urljoin(source_url.geturl() + "/", purl.namespace))
+            subdir = unquote(purl.namespace)
 
         target_dir = self.directory_for(purl.type, repo_url, subdir=subdir)
 
-        file_name = urllib.parse.unquote(purl.name)
+        file_name = unquote(purl.name)
 
-        if source_url.startswith("file://"):
-            source_file = os.path.expanduser(source_url[7:] + file_name)
-            if not Path(source_file).is_file():
+        if source_url.scheme == "file":
+            source_file = Path(source_url.path, file_name).expanduser()
+
+            if not source_file.is_file():
                 return Result.fail(f"Unable to locate file {source_file}")
 
             self.get_logger().info(
@@ -55,10 +57,12 @@ class CollectRawPlugin(CollectorPlugin):
             shutil.copy(source_file, target_dir)
             return Result.success()
 
+        download_url = urljoin(source_url.geturl(), file_name)
+
         self.get_logger().info(
-            f"Downloading from {source_url + file_name} to file {target_dir + file_name}"
+            f"Downloading from {download_url} to file {target_dir.joinpath(file_name)}"
         )
 
-        response = download_file(source_url + file_name, target_dir + file_name, creds)
+        response = download_file(download_url, target_dir.joinpath(file_name), creds)
 
         return Result.from_http_response(response)
