@@ -21,7 +21,7 @@ from urllib.parse import quote_plus
 
 from hoppr_cyclonedx_models.cyclonedx_1_4 import Component  # type: ignore
 from packageurl import PackageURL  # type: ignore
-from typer import echo, secho, colors
+from typer import colors, echo, secho
 
 from hoppr.base_plugins.hoppr import HopprPlugin
 from hoppr.configs.manifest import Manifest
